@@ -6,6 +6,8 @@ function _aws_cdk_assertions_MatchCapture(p) {
         _aws_cdk_assertions_Capture(p.capture);
     visitedObjects.delete(p);
 }
+function _aws_cdk_assertions_Matcher(p) {
+}
 function _aws_cdk_assertions_MatchFailure(p) {
     if (p == null)
         return;
@@ -14,8 +16,6 @@ function _aws_cdk_assertions_MatchFailure(p) {
         _aws_cdk_assertions_Matcher(p.matcher);
     visitedObjects.delete(p);
 }
-function _aws_cdk_assertions_Matcher(p) {
-}
 function _aws_cdk_assertions_Capture(p) {
 }
 function _aws_cdk_assertions_Template(p) {
@@ -41,5 +41,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_assertions_MatchCapture, _aws_cdk_assertions_MatchFailure, _aws_cdk_assertions_Matcher, _aws_cdk_assertions_Capture, _aws_cdk_assertions_Template, _aws_cdk_assertions_Annotations, _aws_cdk_assertions_MatchResult, _aws_cdk_assertions_Match };
+module.exports = { print, _aws_cdk_assertions_MatchCapture, _aws_cdk_assertions_Matcher, _aws_cdk_assertions_MatchFailure, _aws_cdk_assertions_Capture, _aws_cdk_assertions_Template, _aws_cdk_assertions_Annotations, _aws_cdk_assertions_MatchResult, _aws_cdk_assertions_Match };
 module.exports.DeprecationError = DeprecationError;
